<?php
/*
Plugin Name: Gravity Forms - Start progress bar at zero percent
Description: Forces the progress bar on multi-page forms to start at zero percent.
Version: 1.2.0
Author: Adrian Gordon
Author URI: http://www.itsupportguides.com
License: GPL2
Text Domain: gravity-forms-start-progress-bar-at-zero-percent

------------------------------------------------------------------------
Copyright 2015 Adrian Gordon

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

*/

if ( ! defined(  'ABSPATH' ) ) {
	die();
}

load_plugin_textdomain( 'gravity-forms-start-progress-bar-at-zero-percent', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' );

add_action( 'admin_notices', array( 'ITSG_GF_Progress_Zero', 'admin_warnings' ), 20 );

if ( !class_exists('ITSG_GF_Progress_Zero') ) {
    class ITSG_GF_Progress_Zero {

		private static $name = 'Gravity Forms - Start progress bar at zero percent';
		private static $slug = 'gravity-forms-start-progress-bar-at-zero-percent';

		/**
         * Construct the plugin object
         */
        public function __construct() {
			// register plugin functions through 'gform_loaded' -
			// this delays the registration until Gravity Forms has loaded, ensuring it does not run before Gravity Forms is available.
            add_action( 'gform_loaded', array( $this, 'register_actions' ) );

        } // END __construct

		/*
         * Register plugin functions
         */
		function register_actions() {
		// register actions
            if ( self::is_gravityforms_installed() ) {

				// addon framework
				require_once( plugin_dir_path( __FILE__ ).'gravity-forms-progressbar-zero-percent-addon.php' );

				// Set progress bar to start at zero
				add_filter( 'gform_progressbar_start_at_zero', function () { return true; } );
			}
		} // END register_actions

		/*
		 *   Handles the plugin options.
		 *   Default values are stored in an array.
		 */
		public static function get_options() {
			$defaults = array(
				'includecss' => true,
			);
			$options = wp_parse_args( get_option( 'gravityformsaddon_itsg_gf_progresszero_settings' ), $defaults );
			return $options;
		} // END get_options

		/*
         * Warning message if Gravity Forms is installed and enabled
         */
		public static function admin_warnings() {
			if ( !self::is_gravityforms_installed() ) {
				printf(
					'<div class="error"><h3>%s</h3><p>%s</p><p>%s</p></div>',
						__( 'Warning', 'gravity-forms-start-progress-bar-at-zero-percent' ),
						sprintf ( __( 'The plugin %s requires Gravity Forms to be installed.', 'gravity-forms-start-progress-bar-at-zero-percent' ), '<strong>'.self::$name.'</strong>' ),
						sprintf ( esc_html__( 'Please %sdownload the latest version of Gravity Forms%s and try again.', 'gravity-forms-start-progress-bar-at-zero-percent' ), '<a href="https://www.e-junkie.com/ecom/gb.php?cl=54585&c=ib&aff=299380" target="_blank">', '</a>' )
					);
			}
		} // END admin_warnings

		/*
         * Check if GF is installed
         */
        private static function is_gravityforms_installed() {
			if ( !function_exists( 'is_plugin_active' ) || !function_exists( 'is_plugin_active_for_network' ) ) {
				require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
			}
			if ( is_multisite() ) {
				return ( is_plugin_active_for_network( 'gravityforms/gravityforms.php' ) || is_plugin_active( 'gravityforms/gravityforms.php' ) );
			} else {
				return is_plugin_active( 'gravityforms/gravityforms.php' );
			}
        } // END is_gravityforms_installed

	}
	$ITSG_GF_Progress_Zero = new ITSG_GF_Progress_Zero();
}